summaryrefslogtreecommitdiff
path: root/fwu/ns_bl2u/ns_bl2u.ld.S
diff options
context:
space:
mode:
Diffstat (limited to 'fwu/ns_bl2u/ns_bl2u.ld.S')
-rw-r--r--fwu/ns_bl2u/ns_bl2u.ld.S7
1 files changed, 4 insertions, 3 deletions
diff --git a/fwu/ns_bl2u/ns_bl2u.ld.S b/fwu/ns_bl2u/ns_bl2u.ld.S
index a45c418..cd6d0cb 100644
--- a/fwu/ns_bl2u/ns_bl2u.ld.S
+++ b/fwu/ns_bl2u/ns_bl2u.ld.S
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2015, ARM Limited and Contributors. All rights reserved.
+ * Copyright (c) 2015-2018, ARM Limited and Contributors. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
@@ -29,6 +29,7 @@
*/
#include <platform_def.h>
+#include <xlat_tables.h>
OUTPUT_FORMAT(PLATFORM_LINKER_FORMAT)
OUTPUT_ARCH(PLATFORM_LINKER_ARCH)
@@ -41,7 +42,7 @@ MEMORY {
SECTIONS
{
. = NS_BL2U_BASE;
- ASSERT(. == ALIGN(4096),
+ ASSERT(. == ALIGN(PAGE_SIZE),
"NS_BL2U_BASE address is not aligned on a page boundary.")
ro . : {
@@ -56,7 +57,7 @@ SECTIONS
* read-only, executable. No RW data from the next section must
* creep in. Ensure the rest of the current memory page is unused.
*/
- . = NEXT(4096); /* Aligned to the size of a 4KB */
+ . = NEXT(PAGE_SIZE); /* Aligned to the size of a page */
__RO_END__ = .;
} >RAM
__RO_SIZE__ = __RO_END__ - __RO_START__;